function [D, Dnorm] = analyze_simmat_gtz(file, norm_funct)

    fprintf('Analyzing: %s\n', file);
    [D, header] = read_simmat(file);
    fprintf('Size: %dx%d\n\n', size(D, 1), size(D, 2));
    % remove everything < 0 (negatively correlated is not relevant)
    D(D<0)=NaN;
    % convert to a cosine/pearson distance for analysis
    D = 1 - D;

    [Sk5, Nk5] = norm_hubness_cf(D, 5);
    [Sk10, Nk10] = norm_hubness_cf(D, 10);
    [Sk20, Nk20] = norm_hubness_cf(D, 20);
    fprintf('Original Data\n');
    fprintf('Hubness (Sk5): %f; Max. hub size: %d\n\n', Sk5, max(Nk5));
    fprintf('Hubness (Sk10): %f; Max. hub size: %d\n\n', Sk10, max(Nk10));
    fprintf('Hubness (Sk20): %f; Max. hub size: %d\n\n', Sk20, max(Nk20));
    
    fprintf('Normalize using: %s()\n', func2str(norm_funct));
    tic();
    Dnorm = norm_funct(D);
    fprintf('Normalization took: %.2fs\n', toc());
    [Sk5Norm, Nk5Norm] = norm_hubness_cf(Dnorm, 5);
    [Sk10Norm, Nk10Norm] = norm_hubness_cf(Dnorm, 10);
    [Sk20Norm, Nk20Norm] = norm_hubness_cf(Dnorm, 20);
    fprintf('New Hubness (Sk5): %f; Max. hub size: %d\n\n', ...
        Sk5Norm, max(Nk5Norm));
    fprintf('New Hubness (Sk10): %f; Max. hub size: %d\n\n', ...
        Sk10Norm, max(Nk10Norm));
    fprintf('New Hubness (Sk20): %f; Max. hub size: %d\n\n', ...
        Sk20Norm, max(Nk20Norm));
    
    newfile = [file '-' func2str(norm_funct)];
    fprintf('Writing normed simmat to: %s\n', newfile);

    % write a pseudo cosine/pearson similarity
    write_simmat(newfile, (1 - Dnorm), header);

    fprintf('Writing done.\n');
end
