function [distm_norm] = mp_emp(distm)

    distm_norm = NaN(size(distm), class(distm));
    n = size(distm, 1);
    
    for i = 1:n
        
        % select only finite distances for MP
        j_idx = i+1:n;
        j_idx = j_idx(isnan(distm(i, j_idx)) == 0);
        j_len = length(j_idx);
        
        % skip if there is nothing to do
        if (j_len == 0)
            continue;
        end
        
        dI = repmat(distm(i, :), j_len, 1);
        dJ = distm(j_idx, :);
        d = repmat(distm(j_idx, i), 1, n);
        
        sIJ_union = sum((dI >= 0) | (dJ >= 0), 2); 
        sIJ_intersect = sum((dI > d) & (dJ > d), 2);
        
        sIJ_overlap = 1 - (sIJ_intersect ./ sIJ_union);
        distm_norm(i, j_idx) = sIJ_overlap';
        distm_norm(j_idx, i) = sIJ_overlap;
    end
end
