function [distm_norm] = mp_gaussi(distm)
    n = size(distm, 1);
    
    if (nargin < 2)
        mean_dm = zeros(1, n, class(distm));
        std_dm = zeros(1, n, class(distm));
        
        for i=1:n
            sel = ~isnan(distm(i, :));
           
            mean_dm(i) = mean(distm(i, sel));
            std_dm(i) = std(distm(i, sel));
        end
    end

    distm_norm = zeros(size(distm), class(distm));
    
    for i=1:n
        
        j_idx = i+1:n;
        j_len = length(j_idx);
        p1 = 1 - normcdf(distm(i, j_idx), ...
            repmat(mean_dm(i), 1, j_len), repmat(std_dm(i), 1, j_len));
        p2 = 1 - normcdf(distm(j_idx, i)', ...
            mean_dm(j_idx), std_dm(j_idx));
        
        distm_norm(i, j_idx) = 1 - p1.*p2;
        distm_norm(j_idx, i) = distm_norm(i, j_idx);
    end
end
